@@ -9,7 +9,7 @@
 
 package Audio::Nama;
 
-use Modern::Perl '2020';
+use Modern::Perl;
 no warnings 'uninitialized';
 
 use Audio::Nama::Globals qw(:all);
@@ -78,6 +78,8 @@ sub read_config {
 	$config->{root_dir} = $config->{opts}->{d} if $config->{opts}->{d};
 	$config->{root_dir} = expand_tilde($config->{root_dir});
 	$config->{sample_rate} = $cfg{abbreviations}{frequency};
+	$config->{hotkeys}->{' '} = $config->{hotkeys}->{Space}; 
+
 	$config->{use_git} and ! git_executable_found() and 
 		say("Config file requests Git version control,
 but the git executable could not be found.
