@@ -29,58 +29,34 @@ use Audio::Nama::Object qw(
 		ops_list			
         ops_data			
 		inserts_data		
+		fade_data			
 		region				
 		attrib 				
 		class				
+        is_mixing           
+		source_tag 			
 
 		);
 @attributes = qw(
-			name
-			bypass
-			id	
-			project			
-			global		
-			profile	
-			user
-			system	
-			track_name
-			track_version_result 
-			track_version_original
-			track_target_original
-			insert				
-			track_cache	
-			track_target
+
+  		name				
+  		project				
+  		global				
+  		profile				
+  		user				
+  		system				
+  		track_name			
+  		track_version_result 	
+  		track_version_original 	
+  		track_target_original 
+  		insert				
+  		track_cache			
+ 		track_target		
+  		bypass				
+  		id					
+
 	) ;
 
-### 	attributes for searching, sorting, used by external functions
-# 		name				# for user-defined effect chains
-# 
-# 		bypass				# used for identifying effect bypass (obsolete)
-# 		id					# effect id, for storing single effect with controllers
-# 							# for bypass (probably obsolete)	
-# 
-# 		project				# true value identifies project-specific effect chain
-# 
-# 		global				# true value identified global effect chain,
-# 							# not project specific, usually user-defined
-# 
-# 		profile				# name of associated effect profile
-# 
-# 		user				# true value identifies user created effect chain
-# 
-# 		system				# true value identifies system generated effect chain
-# 
-# 		track_name			# applies to a track of this name
-# 
-# 		track_version_result 	# WAV version of track after caching
-# 
-# 		track_version_original 	# WAV version of track before caching 
-# 
-# 		insert				# true value identifies belonging to an insert
-# 		
-# 		track_cache			# true value identifies belonging to track caching
-#
-# 		track_target_original #	WAV files were from this track
 
 %is_attribute = map{ $_ => 1 } @attributes;
 initialize();
@@ -129,16 +105,14 @@ sub new {
 		$vals{inserts_data} ||= [];
 		$vals{ops_list} 	||= [];
 		$vals{ops_data} 	||= {};
-		croak "undeclared field in: @_" if grep{ ! $_is_field{$_} } keys %vals;
+		$vals{fade_data}    ||= [];
+		my @und = grep{ ! $_is_field{$_} } keys %vals;
+		croak "undeclared field @und in: @_" if @und;
 		croak "must have exactly one of 'global' or 'project' fields defined" 
 			unless ($vals{attrib}{global} xor $vals{attrib}{project});
 
 		logpkg(__FILE__,__LINE__,'debug','constructor arguments ', sub{ json_out(\%vals) });
 
-		# we expect some effects
-		logpkg(__FILE__,__LINE__,'warn',"Nether ops_list or nor insert_data is present") 
-			if ! scalar @{$vals{ops_list}} and ! scalar @{$vals{inserts_data}};
-
 		my $ops_data = {};
 		# ops data is taken preferentially 
 		# from ops_data argument, with fallback
@@ -147,7 +121,7 @@ sub new {
 		# in both cases, we clone the data structures
 		# to ensure we don't damage the original
 		
-		map { 	
+		for (@{$vals{ops_list}}){ 	
 
 			if ( $vals{ops_data}->{$_} )
 											
@@ -162,7 +136,7 @@ sub new {
 				$ops_data->{$_} = $filtered_op_data;
 			}
 
-		} @{$vals{ops_list}};
+		} ;
 		
 
 		$vals{ops_data} = $ops_data;
@@ -281,7 +255,7 @@ sub add_ops {
 	} else {
 		@ops_list = @{$self->ops_list};
 	}
-	map 
+	for (@ops_list)
 	{	
 		my $args = 
 		{
@@ -316,8 +290,7 @@ sub add_ops {
 			map{ $self->parent_id($_) =~ s/^$orig_id$/$new_id/  } @{$self->ops_list}
 		}
 		
-	} @ops_list;
-	\@added
+	}
 }
 sub add_inserts {
 	my ($self, $track) = @_;
@@ -349,18 +322,27 @@ sub add_region {
 }
 
 sub add {
-	my ($self, $track, $successor) = @_;
+	my ($self, $track) = @_;
 	# TODO stop_do_start should take place at this level
 	# possibly reconfiguring engine
 	my $args = {};
-	$args->{before} = $successor;
 	$args->{surname} = $self->name if $self->name;
-	my $added = $self->add_ops($track, $args);
+	$self->add_ops($track, $args);
+	#$track->{ops} = dclone($self->ops_list);
 	$self->add_inserts($track);
 	$self->add_region($track) if $self->region;
-	$added
+	$self->add_fades($track) if $self->fade_data;
+	1 # succeeded 
 
 }
+
+sub add_fades {
+	my ($self, $track) = @_;
+	map{ 
+		my %h = %$_; 
+		my $fade = Audio::Nama::Fade->new( %h, track => $track->name ) ;
+	} @{ $self->{fade_data} }
+}
 sub destroy {
 	my $self = shift;
 	delete $by_index{$self->n};
@@ -441,18 +423,18 @@ sub DESTROY {}
 
 package Audio::Nama;
 sub add_effect_chain {
-	my ($name, $track, $successor) = @_;
+	my ($name, $track) = @_;
 	my ($ec) = Audio::Nama::EffectChain::find(
 		unique => 1, 
 		user   => 1, 
 		name   => $name,
 	);
-	if( $ec ){ $ec->add($Audio::Nama::this_track, $successor) }
+	if( $ec ){ $ec->add($Audio::Nama::this_track) }
 	else { Audio::Nama::throw("$name: effect chain not found") }
 	1;
 }
 sub new_effect_profile {
-	logsub("&new_effect_profile");
+	logsub((caller(0))[3]);
 	my ($bunch, $profile) = @_;
 	my @tracks = bunch_tracks($bunch);
 	Audio::Nama::pager( qq(effect profile "$profile" created for tracks: @tracks) );
@@ -462,20 +444,20 @@ sub new_effect_profile {
 			user		=> 1,
 			global		=> 1,
 			track_name	=> $_,
-			ops_list	=> [ $tn{$_}->fancy_ops ],
+			ops_list	=> [ $tn{$_}->user_ops ],
 			inserts_data => $tn{$_}->inserts,
 		);
 	} @tracks;
 }
 sub delete_effect_profile { 
-	logsub("&delete_effect_profile");
+	logsub((caller(0))[3]);
 	my $name = shift;
 	Audio::Nama::pager( qq(deleting effect profile: $name) );
 	map{ $_->destroy} Audio::Nama::EffectChain::find( profile => $name );
 }
 
 sub apply_effect_profile {  # overwriting current effects
-	logsub("&apply_effect_profile");
+	logsub((caller(0))[3]);
 	my ($profile) = @_;
 	my @chains = Audio::Nama::EffectChain::find(profile => $profile);
 
