@@ -1,7 +1,7 @@
 {
 package Audio::Nama::Engine;
 our $VERSION = 1.0;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Carp;
 our @ISA;
 our %by_name;
@@ -138,7 +138,7 @@ sub sync_action {
 {
 package Audio::Nama::NetEngine;
 our $VERSION = 1.0;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Audio::Nama::Log qw(logpkg logit);
 use Audio::Nama::Globals qw(:all);
 use Carp qw(carp);
@@ -293,7 +293,7 @@ sub configure {
 {
 package Audio::Nama::LibEngine;
 our $VERSION = 1.0;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Log qw(logit);
 our @ISA = 'Audio::Nama::Engine';
@@ -327,7 +327,7 @@ sub configure { Audio::Nama::NetEngine::configure(@_) }
 } # end package
 { 
 package Audio::Nama::MidiEngine;
-use Modern::Perl '2020';
+use Modern::Perl;
 use SUPER;
 use Audio::Nama::Globals qw($config %tn);
 our @ISA = 'Audio::Nama::Engine';
