@@ -1,7 +1,7 @@
 # ----------- Logging ------------
 
 package Audio::Nama::Log;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Log::Log4perl qw(get_logger :levels);
 use Exporter;
 use Carp qw(carp cluck confess croak);
